@@ -980,7 +980,7 @@ eog_image_real_load (EogImage *img,
 		) {
 			gchar *file_path;
 			/* Keep the object for rendering */
-			priv->svg = rsvg_handle_new ();
+			priv->svg = rsvg_handle_new_with_flags (RSVG_HANDLE_FLAG_KEEP_IMAGE_DATA);
 			use_rsvg = (priv->svg != NULL);
 			file_path = g_file_get_path (priv->file);
 			rsvg_handle_set_base_uri (priv->svg, file_path);
